From fa2d9453656641002802d8165e80adb9e6a729d2 Mon Sep 17 00:00:00 2001
From: Scott Garman <scott.a.garman@intel.com>
Date: Thu, 14 Apr 2016 12:28:57 +0200
Subject: [PATCH] Disable use of syslog for sysroot

Disable use of syslog to prevent sysroot user and group additions from
writing entries to the host's syslog. This patch should only be used
with the shadow-native recipe.

Upstream-Status: Inappropriate [disable feature]

Signed-off-by: Scott Garman <scott.a.garman@intel.com>
Signed-off-by: Peter Kjellerstedt <peter.kjellerstedt@axis.com>
Signed-off-by: Chen Qi <Qi.Chen@windriver.com>

---
 src/groupadd.c  | 3 +++
 src/groupdel.c  | 3 +++
 src/groupmems.c | 3 +++
 src/groupmod.c  | 3 +++
 src/useradd.c   | 3 +++
 src/userdel.c   | 3 +++
 src/usermod.c   | 3 +++
 7 files changed, 21 insertions(+)

diff --git a/src/groupadd.c b/src/groupadd.c
index 2dd8eec..e9c4bb7 100644
--- a/src/groupadd.c
+++ b/src/groupadd.c
@@ -34,6 +34,9 @@
 
 #ident "$Id$"
 
+/* Disable use of syslog since we're running this command against a sysroot */
+#undef USE_SYSLOG
+
 #include <ctype.h>
 #include <fcntl.h>
 #include <getopt.h>
diff --git a/src/groupdel.c b/src/groupdel.c
index f941a84..5a70056 100644
--- a/src/groupdel.c
+++ b/src/groupdel.c
@@ -34,6 +34,9 @@
 
 #ident "$Id$"
 
+/* Disable use of syslog since we're running this command against a sysroot */
+#undef USE_SYSLOG
+
 #include <ctype.h>
 #include <fcntl.h>
 #include <grp.h>
diff --git a/src/groupmems.c b/src/groupmems.c
index fc91c8b..2842514 100644
--- a/src/groupmems.c
+++ b/src/groupmems.c
@@ -32,6 +32,9 @@
 
 #include <config.h>
 
+/* Disable use of syslog since we're running this command against a sysroot */
+#undef USE_SYSLOG
+
 #include <fcntl.h>
 #include <getopt.h>
 #include <grp.h>
diff --git a/src/groupmod.c b/src/groupmod.c
index 1dca5fc..bc14438 100644
--- a/src/groupmod.c
+++ b/src/groupmod.c
@@ -34,6 +34,9 @@
 
 #ident "$Id$"
 
+/* Disable use of syslog since we're running this command against a sysroot */
+#undef USE_SYSLOG
+
 #include <ctype.h>
 #include <fcntl.h>
 #include <getopt.h>
diff --git a/src/useradd.c b/src/useradd.c
index 4af0f7c..1b7bf06 100644
--- a/src/useradd.c
+++ b/src/useradd.c
@@ -34,6 +34,9 @@
 
 #ident "$Id$"
 
+/* Disable use of syslog since we're running this command against a sysroot */
+#undef USE_SYSLOG
+
 #include <assert.h>
 #include <ctype.h>
 #include <errno.h>
diff --git a/src/userdel.c b/src/userdel.c
index cc951e5..153e0be 100644
--- a/src/userdel.c
+++ b/src/userdel.c
@@ -34,6 +34,9 @@
 
 #ident "$Id$"
 
+/* Disable use of syslog since we're running this command against a sysroot */
+#undef USE_SYSLOG
+
 #include <assert.h>
 #include <errno.h>
 #include <fcntl.h>
diff --git a/src/usermod.c b/src/usermod.c
index 05b9871..21c6da9 100644
--- a/src/usermod.c
+++ b/src/usermod.c
@@ -34,6 +34,9 @@
 
 #ident "$Id$"
 
+/* Disable use of syslog since we're running this command against a sysroot */
+#undef USE_SYSLOG
+
 #include <assert.h>
 #include <ctype.h>
 #include <errno.h>
